@@ -1,10 +1,17 @@
 import os
+from copy import copy
+from difflib import unified_diff
 from sqlalchemy import *
 from sqlalchemy.orm import *
 from model import *
 from cStringIO import StringIO
 from cgi import FieldStorage
 
+#try:
+import xml.etree.ElementTree as etree
+#except ImportError:
+#    import cElementTree as etree
+
 session = None
 engine = None
 connect = None
@@ -13,6 +20,41 @@ sorted_user_columns = ['_password', 'created', 'display_name', 'email_address',
                        'groups', 'password', 'sprox_id', 'town',
                        'town_id', 'user_id', 'user_name']
 
+def remove_whitespace_nodes(node):
+    new_node = copy(node)
+    new_node._children = []
+    if new_node.text and new_node.text.strip() == '':
+        new_node.text = ''
+    if new_node.tail and new_node.tail.strip() == '':
+        new_node.tail = ''
+    for child in node.getchildren():
+        if child is not None:
+            child = remove_whitespace_nodes(child)
+        new_node.append(child)
+    return new_node
+
+def fix_xml(needle):
+    needle_node   = etree.fromstring(needle)
+    needle_node = remove_whitespace_nodes(needle_node)
+#    import ipdb; ipdb.set_trace();
+    needle_s = etree.tostring(needle_node)
+    return needle_s
+
+def in_xml(needle, haystack):
+    needle_s, haystack_s = map(fix_xml, (needle, haystack))
+    return needle_s in haystack_s
+
+def eq_xml(needle, haystack):
+    needle_s, haystack_s = map(fix_xml, (needle, haystack))
+        
+    return needle_s == haystack_s
+
+def assert_in_xml(needle, haystack):
+    assert in_xml(needle, haystack), "%s not found in %s"%(needle, haystack)
+
+def assert_eq_xml(needle, haystack):
+    assert eq_xml(needle, haystack), "%s does not equal %s"%(needle, haystack)
+
 database_setup=False
 def setup_database():
     global session, engine, database_setup, connect, metadata
